@@ -1,6 +1,3 @@
-extern crate kqueue_sys;
-extern crate libc;
-
 use kqueue_sys::{kevent, kqueue};
 use libc::{pid_t, timespec, uintptr_t};
 use std::convert::{AsRef, Into};
@@ -107,8 +104,8 @@ impl Into<usize> for Ident {
 
 impl PartialEq<Ident> for Ident {
     fn eq(&self, other: &Ident) -> bool {
-        match self {
-            &Ident::Filename(_, ref name) => {
+        match *self {
+            Ident::Filename(_, ref name) => {
                 if let &Ident::Filename(_, ref othername) = other {
                     name == othername
                 } else {
@@ -122,12 +119,12 @@ impl PartialEq<Ident> for Ident {
 
 impl Ident {
     fn as_usize(&self) -> usize {
-        match self {
-            &Ident::Filename(fd, _) => fd as usize,
-            &Ident::Fd(fd) => fd as usize,
-            &Ident::Pid(pid) => pid as usize,
-            &Ident::Signal(sig) => sig as usize,
-            &Ident::Timer(timer) => timer as usize,
+        match *self {
+            Ident::Filename(fd, _) => fd as usize,
+            Ident::Fd(fd) => fd as usize,
+            Ident::Pid(pid) => pid as usize,
+            Ident::Signal(sig) => sig as usize,
+            Ident::Timer(timer) => timer as usize,
         }
     }
 }
@@ -141,7 +138,7 @@ impl Watcher {
         } else {
             Ok(Watcher {
                 watched: Vec::new(),
-                queue: queue,
+                queue,
                 started: false,
                 opts: Default::default(),
             })
@@ -160,8 +157,8 @@ impl Watcher {
         flags: FilterFlag,
     ) -> Result<()> {
         let watch = Watched {
-            filter: filter,
-            flags: flags,
+            filter,
+            flags,
             ident: Ident::Pid(pid),
         };
 
@@ -180,8 +177,8 @@ impl Watcher {
     ) -> Result<()> {
         let file = File::open(filename.as_ref())?;
         let watch = Watched {
-            filter: filter,
-            flags: flags,
+            filter,
+            flags,
             ident: Ident::Filename(
                 file.into_raw_fd(),
                 filename.as_ref().to_string_lossy().into_owned(),
@@ -197,8 +194,8 @@ impl Watcher {
 
     pub fn add_fd(&mut self, fd: RawFd, filter: EventFilter, flags: FilterFlag) -> Result<()> {
         let watch = Watched {
-            filter: filter,
-            flags: flags,
+            filter,
+            flags,
             ident: Ident::Fd(fd),
         };
 
@@ -217,8 +214,8 @@ impl Watcher {
         let mut kev: Vec<kevent> = Vec::with_capacity(1);
         kev.push(kevent {
             ident: ident.as_usize(),
-            filter: filter,
-            flags: EV_DELETE,
+            filter,
+            flags: EventFlag::EV_DELETE,
             fflags: FilterFlag::empty(),
             data: 0,
             udata: ptr::null_mut(),
@@ -322,9 +319,9 @@ impl Watcher {
                 ident: raw_ident,
                 filter: watched.filter,
                 flags: if self.opts.clear {
-                    EV_ADD | EV_CLEAR
+                    EventFlag::EV_ADD | EventFlag::EV_CLEAR
                 } else {
-                    EV_ADD
+                    EventFlag::EV_ADD
                 },
                 fflags: watched.flags,
                 data: 0,
@@ -446,15 +443,15 @@ impl Event {
             EventFilter::EVFILT_SIGNAL => EventData::Signal(ev.data as usize),
             EventFilter::EVFILT_TIMER => EventData::Timer(ev.data as usize),
             EventFilter::EVFILT_PROC => {
-                let inner = if ev.fflags.contains(NOTE_EXIT) {
+                let inner = if ev.fflags.contains(FilterFlag::NOTE_EXIT) {
                     Proc::Exit(ev.data as usize)
-                } else if ev.fflags.contains(NOTE_FORK) {
+                } else if ev.fflags.contains(FilterFlag::NOTE_FORK) {
                     Proc::Fork
-                } else if ev.fflags.contains(NOTE_EXEC) {
+                } else if ev.fflags.contains(FilterFlag::NOTE_EXEC) {
                     Proc::Exec
-                } else if ev.fflags.contains(NOTE_TRACK) {
+                } else if ev.fflags.contains(FilterFlag::NOTE_TRACK) {
                     Proc::Track(ev.data as libc::pid_t)
-                } else if ev.fflags.contains(NOTE_CHILD) {
+                } else if ev.fflags.contains(FilterFlag::NOTE_CHILD) {
                     Proc::Child(ev.data as libc::pid_t)
                 } else {
                     panic!("not supported: {:?}", ev.fflags)
@@ -463,19 +460,19 @@ impl Event {
                 EventData::Proc(inner)
             }
             EventFilter::EVFILT_VNODE => {
-                let inner = if ev.fflags.contains(NOTE_DELETE) {
+                let inner = if ev.fflags.contains(FilterFlag::NOTE_DELETE) {
                     Vnode::Delete
-                } else if ev.fflags.contains(NOTE_WRITE) {
+                } else if ev.fflags.contains(FilterFlag::NOTE_WRITE) {
                     Vnode::Write
-                } else if ev.fflags.contains(NOTE_EXTEND) {
+                } else if ev.fflags.contains(FilterFlag::NOTE_EXTEND) {
                     Vnode::Extend
-                } else if ev.fflags.contains(NOTE_ATTRIB) {
+                } else if ev.fflags.contains(FilterFlag::NOTE_ATTRIB) {
                     Vnode::Attrib
-                } else if ev.fflags.contains(NOTE_LINK) {
+                } else if ev.fflags.contains(FilterFlag::NOTE_LINK) {
                     Vnode::Link
-                } else if ev.fflags.contains(NOTE_RENAME) {
+                } else if ev.fflags.contains(FilterFlag::NOTE_RENAME) {
                     Vnode::Rename
-                } else if ev.fflags.contains(NOTE_REVOKE) {
+                } else if ev.fflags.contains(FilterFlag::NOTE_REVOKE) {
                     Vnode::Revoke
                 } else {
                     panic!("not supported")
@@ -496,10 +493,7 @@ impl Event {
             _ => panic!("not supported"),
         };
 
-        Event {
-            ident: ident,
-            data: data,
-        }
+        Event { ident, data }
     }
 
     pub fn from_error(ev: kevent, watcher: &Watcher) -> Event {
@@ -515,7 +509,7 @@ impl Event {
 
         Event {
             data: EventData::Error(io::Error::last_os_error()),
-            ident: ident,
+            ident,
         }
     }
 
@@ -543,18 +537,20 @@ impl<'a> Iterator for EventIter<'a> {
 
 #[cfg(test)]
 mod tests {
-    use super::{EventData, EventFilter, Ident, Vnode, Watcher, NOTE_WRITE};
+    use super::{EventData, EventFilter, FilterFlag, Ident, Vnode, Watcher};
     use std::fs;
     use std::io::Write;
+    use std::path::Path;
+    use tempfile;
 
     #[test]
     fn test_new_watcher() {
         let mut watcher = Watcher::new().unwrap();
-        let file = fs::File::create("testing.txt").unwrap();
+        let file = tempfile::tempfile().unwrap();
 
         assert!(
             watcher
-                .add_file(&file, EventFilter::EVFILT_VNODE, NOTE_WRITE)
+                .add_file(&file, EventFilter::EVFILT_VNODE, FilterFlag::NOTE_WRITE)
                 .is_ok(),
             "add failed"
         );
@@ -563,25 +559,26 @@ mod tests {
 
     #[test]
     fn test_filename() {
-        let filename = "/tmp/testing.txt";
         let mut watcher = match Watcher::new() {
             Ok(wat) => wat,
             Err(_) => panic!("new failed"),
         };
 
-        {
-            assert!(fs::File::create(filename).is_ok(), "file creation failed");
-        };
+        let file = tempfile::NamedTempFile::new().unwrap();
 
         assert!(
             watcher
-                .add_filename(filename, EventFilter::EVFILT_VNODE, NOTE_WRITE)
+                .add_filename(
+                    file.path(),
+                    EventFilter::EVFILT_VNODE,
+                    FilterFlag::NOTE_WRITE
+                )
                 .is_ok(),
             "add failed"
         );
         assert!(watcher.watch().is_ok(), "watch failed");
 
-        let mut new_file = match fs::OpenOptions::new().write(true).open(filename) {
+        let mut new_file = match fs::OpenOptions::new().write(true).open(file.path()) {
             Ok(fil) => fil,
             Err(_) => panic!("open failed"),
         };
@@ -594,26 +591,23 @@ mod tests {
         };
 
         match ev.ident {
-            Ident::Filename(_, name) => assert!(name == filename),
+            Ident::Filename(_, name) => assert!(Path::new(&name) == file.path()),
             _ => assert!(false),
         };
     }
 
     #[test]
     fn test_file() {
-        let filename = "/tmp/testing.txt";
         let mut watcher = match Watcher::new() {
             Ok(wat) => wat,
             Err(_) => panic!("new failed"),
         };
 
-        let file_res = fs::File::create(filename);
-        assert!(file_res.is_ok(), "file creation failed");
-        let mut file = file_res.unwrap();
+        let mut file = tempfile::tempfile().unwrap();
 
         assert!(
             watcher
-                .add_file(&file, EventFilter::EVFILT_VNODE, NOTE_WRITE)
+                .add_file(&file, EventFilter::EVFILT_VNODE, FilterFlag::NOTE_WRITE)
                 .is_ok(),
             "add failed"
         );
@@ -633,19 +627,17 @@ mod tests {
 
     #[test]
     fn test_delete_filename() {
-        let filename = "/tmp/testing.txt";
         let mut watcher = match Watcher::new() {
             Ok(wat) => wat,
             Err(_) => panic!("new failed"),
         };
 
-        {
-            assert!(fs::File::create(filename).is_ok(), "file creation failed");
-        };
+        let file = tempfile::NamedTempFile::new().unwrap();
+        let filename = file.path();
 
         assert!(
             watcher
-                .add_filename(filename, EventFilter::EVFILT_VNODE, NOTE_WRITE)
+                .add_filename(filename, EventFilter::EVFILT_VNODE, FilterFlag::NOTE_WRITE)
                 .is_ok(),
             "add failed"
         );
@@ -660,29 +652,66 @@ mod tests {
 
     #[test]
     fn test_dupe() {
-        let filename = "/tmp/testing.txt";
         let mut watcher = match Watcher::new() {
             Ok(wat) => wat,
             Err(_) => panic!("new failed"),
         };
 
-        {
-            assert!(fs::File::create(filename).is_ok(), "file creation failed");
-        };
+        let file = tempfile::NamedTempFile::new().unwrap();
+        let filename = file.path();
 
         assert!(
             watcher
-                .add_filename(filename, EventFilter::EVFILT_VNODE, NOTE_WRITE)
+                .add_filename(filename, EventFilter::EVFILT_VNODE, FilterFlag::NOTE_WRITE)
                 .is_ok(),
             "add failed"
         );
         assert!(
             watcher
-                .add_filename(filename, EventFilter::EVFILT_VNODE, NOTE_WRITE)
+                .add_filename(filename, EventFilter::EVFILT_VNODE, FilterFlag::NOTE_WRITE)
                 .is_ok(),
             "second add failed"
         );
 
         assert!(watcher.watched.len() == 1);
     }
+
+    #[test]
+    fn test_two_files() {
+        let mut watcher = match Watcher::new() {
+            Ok(wat) => wat,
+            Err(_) => panic!("new failed"),
+        };
+
+        let mut first_file = tempfile::tempfile().unwrap();
+        let mut second_file = tempfile::tempfile().unwrap();
+
+        assert!(
+            watcher
+                .add_file(
+                    &first_file,
+                    EventFilter::EVFILT_VNODE,
+                    FilterFlag::NOTE_WRITE
+                )
+                .is_ok(),
+            "add failed"
+        );
+
+        assert!(
+            watcher
+                .add_file(
+                    &second_file,
+                    EventFilter::EVFILT_VNODE,
+                    FilterFlag::NOTE_WRITE
+                )
+                .is_ok(),
+            "add failed"
+        );
+
+        assert!(watcher.watch().is_ok(), "watch failed");
+        assert!(first_file.write_all(b"foo").is_ok(), "write failed");
+        assert!(second_file.write_all(b"foo").is_ok(), "write failed");
+        assert!(watcher.iter().next().is_some());
+        assert!(watcher.iter().next().is_some());
+    }
 }
